@@ -12,8 +12,10 @@
 
 #' Get a B.C. spatial layer
 #'
+#'
 #' @param layer the name of the layer. The list of available layers can be
 #' obtained by running `available_layers()`
+#'
 #' @inheritParams bc_bound_hres
 #'
 #' @return the layer requested
@@ -22,17 +24,27 @@
 #' @examples
 #' \dontrun{
 #'  get_layer("bc_bound_hres")
-#'
-#'  # As a "Spatial" (sp) object
-#'  get_layer("watercourses_15M")
 #' }
-get_layer <- function(layer, class = c("sf", "sp"), ask = TRUE, force = FALSE) {
+get_layer <- function(layer, class = deprecated(), ask = interactive(), force = FALSE) {
 
   if (!is.character(layer))
     stop("You must refer to the map layer as a character string (in 'quotes')\n
          Use the function available_layers() to get a list of layers")
 
-  class <- match.arg(class)
+  if (lifecycle::is_present(class)) {{
+    # This is a bit convoluted but ensures that the deprecation
+    # message only gets triggered if it hasn't already been triggered
+    # by one of the shortcut functions. caller will be NULL if
+    # it's called from the global environment.
+    caller <- rlang::caller_call()
+    caller_name <- if (is.null(caller)) caller else rlang::call_name(caller)
+    if (is.null(caller_name) ||
+        !caller_name %in% c(shortcut_layer_names(), "combine_nr_rd")) {
+      deprecate_sp('bcmaps::get_layer(class)')
+    }
+    class <- match.arg(class, choices = c('sf', 'sp'))
+  }}
+
   available <- available_layers()
 
   available_row <- available[available[["layer_name"]] == layer, ]
@@ -67,6 +79,7 @@ convert_to_sp <- function(sf_obj) {
   methods::as(ret, "Spatial")
 }
 
+
 #' List available data layers
 #'
 #' A data.frame of all available layers in the bcmaps package. This drawn
@@ -113,6 +126,10 @@ shortcut_layers <- function(){
   al
 }
 
+shortcut_layer_names <- function() {
+  shortcut_layers()[["layer_name"]]
+}
+
 get_catalogue_data <- function(what, release = "latest", force = FALSE, ask = TRUE) {
   fname <- paste0(what, ".rds")
   dir <- data_dir()
