@@ -140,7 +140,10 @@ if (require("raster") && require("stars")) {
   skip_if_offline()
 
   pol1 <- mapsheets_50K()[1,]
-  pol2 <- mapsheets_50K(class = "sp")[1,]
+  pol2 <- withr::with_options(
+    list(lifecycle_verbosity = "quiet"),
+    mapsheets_50K(class = "sp")[1,]
+  )
   r <- raster(mapsheets_50K()[1,])
   s <- st_as_stars(r)
   bound_box <- st_bbox(s)
